@@ -197,7 +197,7 @@ SSE_C = {
 
 
 SSE_C_KEY = {
-    'name': 'sse-c-key',
+    'name': 'sse-c-key', 'cli_type_name': 'blob',
     'help_text': (
         'The customer-provided encryption key to use to server-side '
         'encrypt the object in S3. If you provide this value, '
@@ -234,7 +234,7 @@ SSE_C_COPY_SOURCE = {
 
 
 SSE_C_COPY_SOURCE_KEY = {
-    'name': 'sse-c-copy-source-key',
+    'name': 'sse-c-copy-source-key', 'cli_type_name': 'blob',
     'help_text': (
         'This parameter should only be specified when copying an S3 object '
         'that was encrypted server-side with a customer-provided '
@@ -249,11 +249,12 @@ SSE_C_COPY_SOURCE_KEY = {
 
 STORAGE_CLASS = {'name': 'storage-class',
                  'choices': ['STANDARD', 'REDUCED_REDUNDANCY', 'STANDARD_IA',
-                             'ONEZONE_IA'],
+                             'ONEZONE_IA', 'INTELLIGENT_TIERING', 'GLACIER'],
                  'help_text': (
                      "The type of storage to use for the object. "
                      "Valid choices are: STANDARD | REDUCED_REDUNDANCY "
-                     "| STANDARD_IA | ONEZONE_IA. "
+                     "| STANDARD_IA | ONEZONE_IA | INTELLIGENT_TIERING "
+                     "| GLACIER. "
                      "Defaults to 'STANDARD'")}
 
 
